@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    stat.c -- a demo program that works similar to the standard stat utility. */
@@ -30,15 +30,11 @@ errno_t stat_cmd(busy_ctx_t *ctx) {
 	}
 
 	aal_stream_init(&stream, NULL, &memory_stream);
-
-	plug_call(object->ent->start.plug->o.item_ops->debug, print, 
-		  &object->ent->start, &stream, 0);
-		
+	objcall(&object->info.start, debug->print, &stream, 0);
 	printf("%s\n", (char *)stream.entity);
-	
 	aal_stream_fini(&stream);
-	reiser4_object_close(object);
 	
+	reiser4_object_close(object);
 	return 0;
 }
 
