@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    pprofile.c -- methods for working with reiser4 profile. */
@@ -50,7 +50,7 @@ void misc_profile_print(void) {
 
 	aal_stream_init(&stream, stdout, &file_stream);
 	
-	aal_stream_format(&stream, "Default profiles:\n");
+	aal_stream_format(&stream, "Default profile:\n");
 
 	reiser4_profile_print(&stream);
 	
