@@ -250,7 +250,7 @@ reiser4_fs_t *reiser4_fs_create(
 	aal_device_t *device,           /* device filesystem will be lie on */
 	fs_hint_t *hint)                /* filesystem hint */
 {
-	reiser4_plug_t *format, *policy, *key;
+  reiser4_plug_t *format, *policy, *node, *key;
 
 	count_t free;
 	reiser4_fs_t *fs;
@@ -288,15 +288,18 @@ reiser4_fs_t *reiser4_fs_create(
 
 	/* Getting tail policy from default params. */
 	policy = reiser4_profile_plug(PROF_POLICY);
-	
+
+	/* Getting node plugin from default params. */
+	node = reiser4_profile_plug(PROF_NODE);
+
 	/* Taking care about key flags in format super block */
 	key = reiser4_profile_plug(PROF_KEY);
 	
 	/* Creates disk format. */
 	
 	fs->format = reiser4_format_create(fs, (reiser4_format_plug_t *)format,
-					   policy->id.id, key->id.id, 
-					   hint->blocks);
+					   policy->id.id, key->id.id,
+					   node->id.id, hint->blocks);
 	if (!fs->format) 
 		goto error_free_status;
 
