@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    object.c -- common code for all reiser4 objects (regular files, directories,
@@ -8,30 +8,36 @@
 #include <reiser4/libreiser4.h>
 
 /* Init object pset by its SD. */
-errno_t reiser4_object_init(object_info_t *info) {
+static errno_t reiser4_object_init(reiser4_object_t *object) {
+	reiser4_place_t *start;
 	sdhint_plug_t plugh;
+	sdhint_plug_t heirh;
 	trans_hint_t trans;
 	stat_hint_t stat;
 	errno_t res;
 	
-	aal_assert("umka-2380", info != NULL);
+	aal_assert("umka-2380", object != NULL);
 
 	aal_memset(&stat, 0, sizeof(stat));
 	aal_memset(&plugh, 0, sizeof(plugh));
+	aal_memset(&heirh, 0, sizeof(heirh));
 	
 	/* Preparing hint and mask */
 	trans.specific = &stat;
 	trans.place_func = NULL;
 	trans.region_func = NULL;
 	trans.shift_flags = SF_DEFAULT;
-	stat.ext[SDEXT_PLUG_ID] = &plugh;
+	stat.ext[SDEXT_PSET_ID] = &plugh;
+	stat.ext[SDEXT_HSET_ID] = &heirh;
 	
-	if (reiser4_place_valid(&info->start)) {
-		if ((res = reiser4_place_fetch(&info->start)))
+	start = &object->info.start;
+	
+	if (reiser4_place_valid(start)) {
+		if ((res = reiser4_place_fetch(start)))
 			return res;
 
 		/* Init is allowed on a SD item only. */
-		if (info->start.plug->id.group != STAT_ITEM)
+		if (start->plug->p.id.group != STAT_ITEM)
 			return -EINVAL;
 	} else {
 		/* Init is allowed on a SD item only. */
@@ -39,24 +45,17 @@ errno_t reiser4_object_init(object_info_t *info) {
 	}
 	
 	/* Getting object plugin by first item coord. */
-	if ((res = plug_call(info->start.plug->o.item_ops->object,
-			     fetch_units, &info->start, &trans)) != 1)
+	if ((res = objcall(start, object->fetch_units, &trans)) != 1)
 		return res;
 	
-	aal_memcpy(&info->opset.plug, &plugh, sizeof(plugh));
+	aal_memcpy(&object->info.pset, &plugh, sizeof(plugh));
+	aal_memcpy(&object->info.hset, &heirh, sizeof(heirh));
+	
+	reiser4_pset_complete((reiser4_tree_t *)object->info.tree, 
+			      &object->info);
 	
 	/* Object plugin must be detected. */
-	return info->opset.plug[OPSET_OBJ] ? 0 : -EINVAL;
-}
-
-/* Helper funtion, which initializes @object->ent by @object->info. */
-object_entity_t *reiser4_object_recognize(object_info_t *info) {
-	if (reiser4_object_init(info))
-		return INVAL_PTR;
-
-	/* Requesting object plugin to open the object on passed @tree and
-	   @place. If it fails, we will continue lookup. */
-	return plug_call(info->opset.plug[OPSET_OBJ]->o.object_ops, open, info);
+	return reiser4_psobj(object) ? 0 : -EINVAL;
 }
 
 /* Tries to open object at @place. Uses @init_func for initializing object
@@ -64,50 +63,44 @@ object_entity_t *reiser4_object_recognize(object_info_t *info) {
    entity initializing and librepair another one, but both they use some amount
    of common code, which was moved to this function and used by both in such a
    manner. */
-reiser4_object_t *reiser4_object_form(reiser4_tree_t *tree,
+reiser4_object_t *reiser4_object_prep(reiser4_tree_t *tree,
 				      reiser4_object_t *parent,
 				      reiser4_key_t *okey,
-				      reiser4_place_t *place,
-				      object_init_t init_func)
+				      reiser4_place_t *place)
 {
 	reiser4_object_t *object;
-	object_info_t info;
 	
 	aal_assert("umka-1508", tree != NULL);
 	aal_assert("umka-1509", place != NULL);
 	aal_assert("vpf-1409",  okey != NULL);
-	aal_assert("vpf-1221",  init_func != NULL);
 
-	aal_memset(&info, 0, sizeof(info));
-	
 	if (!(object = aal_calloc(sizeof(*object), 0)))
-		return INVAL_PTR;
+		return NULL;
 
 	/* Initializing object info. */
-	info.tree = (tree_entity_t *)tree;
+	object->info.tree = (tree_entity_t *)tree;
 
 	/* Putting object key to info struct. We may want to open and fix 
 	   the object even if @place->key does not match @okey. */
-	aal_memcpy(&info.object, okey, sizeof(*okey));
+	aal_memcpy(&object->info.object, okey, sizeof(*okey));
 
 	/* Copying item coord. */
-	aal_memcpy(&info.start, place, sizeof(*place));
+	aal_memcpy(&object->info.start, place, sizeof(*place));
 
 	/* Parent is not passed. Using object's key as parent's one. */
 	if (parent) {
-		aal_memcpy(&info.parent, &parent->ent->object, 
-			   sizeof(info.parent));
+		aal_memcpy(&object->info.parent, 
+			   &parent->info.object, 
+			   sizeof(object->info.parent));
 	}
 
-	/* Calling @init_func. It returns zero for success. */
-	if (!(object->ent = init_func(&info)) || object->ent == INVAL_PTR)
-		goto error_free_object;
+	/* Try to init on the StatData. */
+	if (reiser4_object_init(object)) {
+		aal_free(object);
+		return NULL;
+	}
 	
 	return object;
-
- error_free_object:
-	aal_free(object);
-	return NULL;
 }
 
 /* This function opens object by its @place. */
@@ -119,10 +112,18 @@ reiser4_object_t *reiser4_object_open(reiser4_tree_t *tree,
 	
 	aal_assert("vpf-1223", place != NULL);
 
-	object = reiser4_object_form(tree, parent, &place->key, place, 
-				     reiser4_object_recognize);
+	if (!(object = reiser4_object_prep(tree, parent, 
+					   &place->key, place)))
+	{
+		return NULL;
+	}
+	
+	if (plugcall(reiser4_psobj(object), open, object)) {
+		aal_free(object);
+		return NULL;
+	}
 
-	return (object == INVAL_PTR ? NULL : object);
+	return object;
 }
 
 /* Try to open the object on the base of the given key. 
@@ -147,7 +148,7 @@ reiser4_object_t *reiser4_object_obtain(reiser4_tree_t *tree,
 		return NULL;
 
 	/* The key must point to the start of the object. */
-	if (reiser4_key_compfull(&place.key, key))
+	if (place.pos.unit != 0 && place.pos.unit != MAX_UINT32)
 		return NULL;
 
 	/* If the pointed item was found, object must be
@@ -175,21 +176,19 @@ uint64_t reiser4_object_size(reiser4_object_t *object) {
 	hint.ext[SDEXT_LW_ID] = &lwh;
 
 	/* Calling objects stat() method. */
-	if (plug_call(objplug(object)->o.object_ops,
-		      stat, object->ent, &hint))
+	if (plugcall(reiser4_psobj(object), stat, object, &hint))
 		return 0;
-
+	
 	return lwh.size;
 }
 
 /* Closes specified object */
-void reiser4_object_close(
-	reiser4_object_t *object)    /* object to be closed */
-{
+void reiser4_object_close(reiser4_object_t *object) {
 	aal_assert("umka-680", object != NULL);
-	aal_assert("umka-1149", object->ent != NULL);
 
-	plug_call(objplug(object)->o.object_ops, close, object->ent);
+	if (reiser4_psobj(object)->close)
+		reiser4_psobj(object)->close(object);
+	
 	aal_free(object);
 }
 
@@ -200,13 +199,11 @@ errno_t reiser4_object_add_entry(
 	entry_hint_t *entry)                /* entry hint to be added */
 {
 	aal_assert("umka-1975", object != NULL);
-	aal_assert("umka-1976", object->ent != NULL);
 
-	if (!objplug(object)->o.object_ops->add_entry)
+	if (!reiser4_psobj(object)->add_entry)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops,
-			 add_entry, object->ent, entry);
+	return plugcall(reiser4_psobj(object), add_entry, object, entry);
 }
 
 /* Removes @entry to @object */
@@ -215,13 +212,11 @@ errno_t reiser4_object_rem_entry(
 	entry_hint_t *entry)                /* entry hint to be added */
 {
 	aal_assert("umka-1977", object != NULL);
-	aal_assert("umka-1978", object->ent != NULL);
     
-	if (!objplug(object)->o.object_ops->rem_entry)
+	if (!reiser4_psobj(object)->rem_entry)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops,
-			 rem_entry, object->ent, entry);
+	return plugcall(reiser4_psobj(object), rem_entry, object, entry);
 }
 
 errno_t reiser4_object_truncate(
@@ -229,10 +224,8 @@ errno_t reiser4_object_truncate(
 	uint64_t n)			    /* the number of entries */
 {
 	aal_assert("umka-1154", object != NULL);
-	aal_assert("umka-1155", object->ent != NULL);
     
-	return plug_call(objplug(object)->o.object_ops,
-			 truncate, object->ent, n);
+	return plugcall(reiser4_psobj(object), truncate, object, n);
 }
 
 /* Adds speficied entry into passed opened dir */
@@ -243,13 +236,11 @@ int64_t reiser4_object_write(
 					       be created */
 {
 	aal_assert("umka-862", object != NULL);
-	aal_assert("umka-863", object->ent != NULL);
     
-	if (!objplug(object)->o.object_ops->write)
+	if (!reiser4_psobj(object)->write)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops,
-			 write, object->ent, buff, n);
+	return plugcall(reiser4_psobj(object), write, object, buff, n);
 }
 
 /* Updates object stat data coord by means of using tree_lookup(). */
@@ -258,11 +249,11 @@ errno_t reiser4_object_refresh(reiser4_object_t *object) {
 	lookup_hint_t hint;
 
 	hint.level = LEAF_LEVEL;
-	hint.key = &object->ent->object;
+	hint.key = &object->info.object;
 
 	hint.collision = NULL;
 
-	tree = (reiser4_tree_t *)object->ent->tree;
+	tree = (reiser4_tree_t *)object->info.tree;
 	
 	switch (reiser4_tree_lookup(tree, &hint, FIND_EXACT, 
 				    object_start(object)))
@@ -274,15 +265,6 @@ errno_t reiser4_object_refresh(reiser4_object_t *object) {
 	}
 }
 
-/* Saves stat data described by @hint to @object stat data item in tree. */
-errno_t reiser4_object_update(reiser4_object_t *object, stat_hint_t *hint) {
-	aal_assert("umka-2572", object != NULL);
-	aal_assert("umka-2573", object->ent != NULL);
-
-	return plug_call(objplug(object)->o.object_ops,
-			 update, object->ent, hint);
-}
-
 errno_t reiser4_object_entry_prep(reiser4_tree_t *tree,
 				  reiser4_object_t *parent,
 				  entry_hint_t *entry,
@@ -300,15 +282,14 @@ errno_t reiser4_object_entry_prep(reiser4_tree_t *tree,
 	/* Preparing @entry to be used for object creating and linking to parent
 	   object. This is name and offset key. */
 	if (parent) {
-		if (!objplug(parent)->o.object_ops->build_entry) {
+		if (!reiser4_psobj(parent)->build_entry) {
 			aal_error("Object %s has not build_entry() method "
 				  "implemented. Is it dir object at all?", 
-				  reiser4_print_inode(&parent->ent->object));
+				  reiser4_print_inode(&parent->info.object));
 			return -EINVAL;
 		}
 		
-		plug_call(objplug(parent)->o.object_ops, 
-			  build_entry, parent->ent, entry);
+		plugcall(reiser4_psobj(parent), build_entry, parent, entry);
 	} else {
 		aal_memcpy(&entry->offset, &tree->key, sizeof(tree->key));
 	}
@@ -317,8 +298,8 @@ errno_t reiser4_object_entry_prep(reiser4_tree_t *tree,
 }
 
 /* Helper function for prepare object key to be used for creating new object. */
-static void reiser4_object_maintain(entry_hint_t *entry,
-				    object_hint_t *hint) 
+static void reiser4_object_maintain(reiser4_object_t *object, 
+				    entry_hint_t *entry) 
 {
 	reiser4_tree_t *tree;
 	oid_t locality;
@@ -326,19 +307,19 @@ static void reiser4_object_maintain(entry_hint_t *entry,
 	oid_t objectid;
 	
 	aal_assert("vpf-1715", entry != NULL);
-	aal_assert("vpf-1716", hint != NULL);
-	aal_assert("vpf-1714", hint->info.tree != NULL);
+	aal_assert("vpf-1714", object != NULL);
+	aal_assert("vpf-1822", object->info.tree != NULL);
 
 	/* Initializing fields and preparing the keys */
-	tree = (reiser4_tree_t *)hint->info.tree;
+	tree = (reiser4_tree_t *)object->info.tree;
 
-	if (hint->info.parent.plug) {
+	if (object->info.parent.plug) {
 		/* Parent if defined, getting locality from it. */
 		objectid = reiser4_oid_allocate(tree->fs->oid);
-		locality = reiser4_key_get_objectid(&hint->info.parent);
+		locality = reiser4_key_get_objectid(&object->info.parent);
 	} else {
 		/* Parent is not defined, root key is used. */
-		aal_memcpy(&hint->info.parent, &tree->key, sizeof(tree->key));
+		aal_memcpy(&object->info.parent, &tree->key, sizeof(tree->key));
 		locality = reiser4_key_get_locality(&tree->key);
 		objectid = reiser4_key_get_objectid(&tree->key);
 		reiser4_oid_set_used(tree->fs->oid, 
@@ -348,13 +329,13 @@ static void reiser4_object_maintain(entry_hint_t *entry,
 	/* New object is identified by its locality and objectid. Set them to
 	   the @object->info.object key and plugin create method will build the
 	   whole key there. */
-	hint->info.object.plug = tree->key.plug;
+	object->info.object.plug = tree->key.plug;
 
 	/* Ordering component of key to be used for object. */
 	ordering = reiser4_key_get_ordering(&entry->offset);
 
 	/* Building object stat data key. */
-	reiser4_key_build_generic(&hint->info.object, KEY_STATDATA_TYPE,
+	reiser4_key_build_generic(&object->info.object, KEY_STATDATA_TYPE,
 				  locality, ordering, objectid, 0);
 }
 
@@ -365,16 +346,16 @@ errno_t reiser4_object_attach(reiser4_object_t *object,
 
 	aal_assert("vpf-1720", object != NULL);
 	
-	if (!objplug(object)->o.object_ops->attach) 
+	if (!reiser4_psobj(object)->attach) 
 		return 0;
 	
-	if ((res = plug_call(objplug(object)->o.object_ops, attach, 
-			     object->ent, parent ? parent->ent : NULL)))
+	if ((res = plugcall(reiser4_psobj(object), attach, 
+			    object, parent ? parent : NULL)))
 	{
 		aal_error("Can't attach %s to %s.",
-			  reiser4_print_inode(&object->ent->object),
+			  reiser4_print_inode(&object->info.object),
 			  parent == NULL ? "itself" :
-			  reiser4_print_inode(&parent->ent->object));
+			  reiser4_print_inode(&parent->info.object));
 	}
 
 	return res;
@@ -389,16 +370,16 @@ errno_t reiser4_object_detach(reiser4_object_t *object,
 
 	aal_assert("vpf-1721", object != NULL);
 
-	if (!objplug(object)->o.object_ops->detach) 
+	if (!reiser4_psobj(object)->detach) 
 		return 0;
 	
-	if ((res = plug_call(objplug(object)->o.object_ops, detach,
-			     object->ent, parent ? parent->ent : NULL))) 
+	if ((res = plugcall(reiser4_psobj(object), detach,
+			    object, parent ? parent : NULL))) 
 	{
 		aal_error("Can't detach %s from %s.",
-			  reiser4_print_inode(&object->ent->object),
+			  reiser4_print_inode(&object->info.object),
 			  parent == NULL ? "itself" :
-			  reiser4_print_inode(&parent->ent->object));
+			  reiser4_print_inode(&parent->info.object));
 	}
 
 	return res;
@@ -406,42 +387,39 @@ errno_t reiser4_object_detach(reiser4_object_t *object,
 
 /* Creates new object on specified filesystem */
 reiser4_object_t *reiser4_object_create(
-	entry_hint_t *entry,                 /* entry hint object to be used */
-	object_hint_t *hint)                 /* object hint */
+	entry_hint_t *entry,			/* entry hint object to be used */
+	object_info_t *info,			/* object init info */
+	object_hint_t *hint)			/* object hint */
 {
 	reiser4_object_t *object;
-	reiser4_plug_t *plug;
 	
-	aal_assert("umka-1128", hint != NULL);
-
-	plug = hint->info.opset.plug[OPSET_OBJ];
-	
-	aal_assert("umka-1917", plug != NULL);
+	aal_assert("umka-1917", info != NULL);
 
 	/* Allocating the memory for object instance */
 	if (!(object = aal_calloc(sizeof(*object), 0)))
 		return NULL;
 
+	aal_memcpy(&object->info, info, sizeof (*info));
+	
 	/* Preparing object info. */
-	reiser4_object_maintain(entry, hint);
-
+	reiser4_object_maintain(object, entry);
+	
+	aal_assert("vpf-1823", reiser4_psobj(object) != NULL);
+	
 	/* Calling object plugin to create its body in the tree */
-	if (!(object->ent = plug_call(plug->o.object_ops, create, hint)))
-		goto error_free_object;
+	if (plugcall(reiser4_psobj(object), create, object, hint)) {
+		aal_free(object);
+		return NULL;
+	}
 
 	return object;
-	
- error_free_object:
-	aal_free(object);
-	return NULL;
 }
 
 /* Removes object body and stat data */
 errno_t reiser4_object_clobber(reiser4_object_t *object) {
 	aal_assert("umka-2297", object != NULL);
 
-	return plug_call(objplug(object)->o.object_ops,
-			 clobber, object->ent);
+	return plugcall(reiser4_psobj(object), clobber, object);
 }
 
 /* Links @child to @object if it is a directory */
@@ -456,23 +434,23 @@ errno_t reiser4_object_link(reiser4_object_t *object,
 	/* Check if we need to add entry in parent @object */
 	if (entry && object) {
 		aal_memcpy(&entry->object, 
-			   &child->ent->object, 
+			   &child->info.object, 
 			   sizeof(entry->offset));
 
 		if ((res = reiser4_object_add_entry(object, entry))) {
 			aal_error("Can't add entry %s to %s.", entry->name, 
-				  reiser4_print_inode(&object->ent->object));
+				  reiser4_print_inode(&object->info.object));
 			return res;
 		}
 	}
 
 	/* Add one hard link to @child. */
-	if (objplug(child)->o.object_ops->link) {
-		if ((res = plug_call(objplug(child)->o.object_ops, 
-				     link, child->ent)))
-		{
+	if (reiser4_psobj(child)->link) {
+		res = plugcall(reiser4_psobj(child), link, child);
+		
+		if (res) {
 			aal_error("Can't link the object %s. ",
-				  reiser4_print_inode(&child->ent->object));
+				  reiser4_print_inode(&child->info.object));
 			
 			goto error_rem_entry;
 		}
@@ -485,18 +463,17 @@ errno_t reiser4_object_link(reiser4_object_t *object,
 	return 0;
 
  error_unlink_child:
-	if (objplug(child)->o.object_ops->unlink) {
-		if (plug_call(objplug(child)->o.object_ops, unlink, child->ent))
-		{
+	if (reiser4_psobj(child)->unlink) {
+		if (plugcall(reiser4_psobj(child), unlink, child)) {
 			aal_error("Can't unlink the object %s.",
-				  reiser4_print_inode(&child->ent->object));
+				  reiser4_print_inode(&child->info.object));
 		}
 	}
 	
  error_rem_entry:
 	if (reiser4_object_rem_entry(object, entry)) {
 		aal_error("Can't remove entry %s in %s.", entry->name,
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 	}
 	
 	return res;
@@ -516,7 +493,7 @@ errno_t reiser4_object_unlink(reiser4_object_t *object, char *name) {
 	/* Getting entry poining to the child. */
 	if (reiser4_object_lookup(object, name, &entry) != PRESENT) {
 		aal_error("Can't find entry %s in %s.", name, 
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 		return -EINVAL;
 	}
 
@@ -529,14 +506,14 @@ errno_t reiser4_object_unlink(reiser4_object_t *object, char *name) {
 	hint.key = &entry.object;
 	hint.collision = NULL;
 	
-	tree = (reiser4_tree_t *)object->ent->tree;
+	tree = (reiser4_tree_t *)object->info.tree;
 	
 	/* Looking up for the victim's statdata place */
 	if (reiser4_tree_lookup(tree, &hint, FIND_EXACT, &place) != PRESENT) {
 		char *key = reiser4_print_key(&entry.object);
 		aal_error("Can't find an item pointed by %s. "
 			  "Entry %s/%s points to nowere.", key, 
-			  reiser4_print_inode(&object->ent->object), 
+			  reiser4_print_inode(&object->info.object), 
 			  name);
 		return -EINVAL;
 	}
@@ -544,7 +521,7 @@ errno_t reiser4_object_unlink(reiser4_object_t *object, char *name) {
 	/* Opening victim object by found place */
 	if (!(child = reiser4_object_open(tree, object, &place))) {
 		aal_error("Can't open %s/%s. Object is corrupted?",
-			  reiser4_print_inode(&object->ent->object), 
+			  reiser4_print_inode(&object->info.object), 
 			  name);
 		return -EINVAL;
 	}
@@ -554,16 +531,15 @@ errno_t reiser4_object_unlink(reiser4_object_t *object, char *name) {
 		return res;
 
 	/* Remove one hard link from child. */
-	if (objplug(child)->o.object_ops->unlink) {
-		if ((res = plug_call(objplug(child)->o.object_ops,
-				     unlink, child->ent)))
+	if (reiser4_psobj(child)->unlink) {
+		if ((res = plugcall(reiser4_psobj(child), unlink, child)))
 			goto error_attach_child;
 	}
 
 	/* Removing entry from @object. */
 	if ((res = reiser4_object_rem_entry(object, &entry))) {
 		aal_error("Can't remove entry %s in %s.", name, 
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 		
 		goto error_link_child;
 	}
@@ -572,10 +548,10 @@ errno_t reiser4_object_unlink(reiser4_object_t *object, char *name) {
 	return 0;
 
  error_link_child:
-	if (objplug(child)->o.object_ops->link) {
-		if (plug_call(objplug(child)->o.object_ops, link, child->ent)) {
+	if (reiser4_psobj(child)->link) {
+		if (plugcall(reiser4_psobj(child), link, child)) {
 			aal_error("Can't link the object %s.",
-				  reiser4_print_inode(&child->ent->object));
+				  reiser4_print_inode(&child->info.object));
 		}
 	}
  error_attach_child:
@@ -593,11 +569,11 @@ errno_t reiser4_object_layout(
 	aal_assert("umka-1469", object != NULL);
 	aal_assert("umka-1470", region_func != NULL);
 
-	if (!objplug(object)->o.object_ops->layout)
+	if (!reiser4_psobj(object)->layout)
 		return 0;
 	
-	return plug_call(objplug(object)->o.object_ops, layout, 
-			 object->ent, region_func, data);
+	return plugcall(reiser4_psobj(object), layout, 
+			object, region_func, data);
 }
 
 /* Enumerates all items object consists of */
@@ -609,11 +585,11 @@ errno_t reiser4_object_metadata(
 	aal_assert("umka-1714", object != NULL);
 	aal_assert("umka-1715", place_func != NULL);
 
-	if (!objplug(object)->o.object_ops->metadata)
+	if (!reiser4_psobj(object)->metadata)
 		return 0;
 	
-	return plug_call(objplug(object)->o.object_ops, metadata, 
-			 object->ent, place_func, data);
+	return plugcall(reiser4_psobj(object), metadata, 
+			object, place_func, data);
 }
 
 /* Makes lookup inside the @object */
@@ -623,20 +599,18 @@ lookup_t reiser4_object_lookup(reiser4_object_t *object,
 	aal_assert("umka-1919", object != NULL);
 	aal_assert("umka-1920", name != NULL);
 
-	if (!objplug(object)->o.object_ops->lookup)
+	if (!reiser4_psobj(object)->lookup)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops, lookup, 
-			 object->ent, (char *)name, (void *)entry);
+	return plugcall(reiser4_psobj(object), lookup, 
+			object, (char *)name, (void *)entry);
 }
 
 /* Loads object stat data to @hint. */
 errno_t reiser4_object_stat(reiser4_object_t *object, stat_hint_t *hint) {
 	aal_assert("umka-2570", object != NULL);
-	aal_assert("umka-2571", object->ent != NULL);
 
-	return plug_call(objplug(object)->o.object_ops,
-			 stat, object->ent, hint);
+	return plugcall(reiser4_psobj(object), stat, object, hint);
 }
 
 /* Resets directory position */
@@ -644,10 +618,9 @@ errno_t reiser4_object_reset(
 	reiser4_object_t *object)    /* dir to be reset */
 {
 	aal_assert("umka-842", object != NULL);
-	aal_assert("umka-843", object->ent != NULL);
+	aal_assert("umka-843", object != NULL);
 
-	return plug_call(objplug(object)->o.object_ops,
-			 reset, object->ent);
+	return plugcall(reiser4_psobj(object), reset, object);
 }
 
 /* Sets directory current position to passed pos */
@@ -656,13 +629,11 @@ errno_t reiser4_object_seek(
 	uint32_t offset)	     /* offset for seeking */
 {
 	aal_assert("umka-1129", object != NULL);
-	aal_assert("umka-1153", object->ent != NULL);
     
-	if (!objplug(object)->o.object_ops->seek)
+	if (!reiser4_psobj(object)->seek)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops,
-			 seek, object->ent, offset);
+	return plugcall(reiser4_psobj(object), seek, object, offset);
 }
 
 /* Change current position in passed @object if it is a directory */
@@ -672,11 +643,10 @@ errno_t reiser4_object_seekdir(reiser4_object_t *object,
 	aal_assert("umka-1979", object != NULL);
 	aal_assert("umka-1980", offset != NULL);
 
-	if (!objplug(object)->o.object_ops->seekdir)
+	if (!reiser4_psobj(object)->seekdir)
 		return -EINVAL;
 
-	return plug_call(objplug(object)->o.object_ops,
-			 seekdir, object->ent, offset);
+	return plugcall(reiser4_psobj(object), seekdir, object, offset);
 }
 
 /* Returns current position in directory */
@@ -684,10 +654,8 @@ uint32_t reiser4_object_offset(
 	reiser4_object_t *object)    /* dir position will be obtained from */
 {
 	aal_assert("umka-875", object != NULL);
-	aal_assert("umka-876", object->ent != NULL);
 
-	return plug_call(objplug(object)->o.object_ops, 
-			 offset, object->ent);
+	return plugcall(reiser4_psobj(object), offset, object);
 }
 
 /* Return current position in passed @object if it is a directory */
@@ -697,11 +665,10 @@ errno_t reiser4_object_telldir(reiser4_object_t *object,
 	aal_assert("umka-1981", object != NULL);
 	aal_assert("umka-1982", offset != NULL);
 
-	if (!objplug(object)->o.object_ops->telldir)
+	if (!reiser4_psobj(object)->telldir)
 		return -EINVAL;
 
-	return plug_call(objplug(object)->o.object_ops,
-			 telldir, object->ent, offset);
+	return plugcall(reiser4_psobj(object), telldir, object, offset);
 }
 
 /* Reads @n bytes of data at the current offset of @object to passed
@@ -712,13 +679,11 @@ int64_t reiser4_object_read(
 	uint64_t n)                 /* buffer size */
 {
 	aal_assert("umka-860", object != NULL);
-	aal_assert("umka-861", object->ent != NULL);
 
-	if (!objplug(object)->o.object_ops->read)
+	if (!reiser4_psobj(object)->read)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops, 
-			 read, object->ent, buff, n);
+	return plugcall(reiser4_psobj(object), read, object, buff, n);
 }
 
 /* Reads entry at current @object offset to passed @entry hint */
@@ -728,42 +693,10 @@ errno_t reiser4_object_readdir(reiser4_object_t *object,
 	aal_assert("umka-1973", object != NULL);
 	aal_assert("umka-1974", entry != NULL);
 
-	if (!objplug(object)->o.object_ops->readdir)
+	if (!reiser4_psobj(object)->readdir)
 		return -EINVAL;
 	
-	return plug_call(objplug(object)->o.object_ops, 
-			 readdir, object->ent, entry);
-}
-
-/* Completes object creating. */
-static reiser4_object_t *reiser4_obj_create(reiser4_object_t *parent,
-					    object_hint_t *hint,
-					    const char *name)
-{
-	reiser4_object_t *object;
-	reiser4_tree_t *tree;
-	entry_hint_t entry;
-	
-	tree = (reiser4_tree_t *)hint->info.tree;
-	
-	if (reiser4_object_entry_prep(tree, parent, &entry, name))
-		return NULL;
-	
-	entry.place_func = NULL;
-	
-	/* Creating object by passed parameters. */
-	if (!(object = reiser4_object_create(&entry, hint)))
-		return NULL;
-
-	if (parent) {
-		if (reiser4_object_link(parent, object, &entry)) {
-			reiser4_object_clobber(object);
-			reiser4_object_close(object);
-			return NULL;
-		}
-	}
-
-	return object;
+	return plugcall(reiser4_psobj(object), readdir, object, entry);
 }
 
 /* Enumerates all enries in @object. Calls @open_func for each of them. Used in
@@ -779,7 +712,7 @@ errno_t reiser4_object_traverse(reiser4_object_t *object,
 	aal_assert("vpf-1103", open_func != NULL);
 
 	/* Check if object has readdir() method implemented. */
-	if (!objplug(object)->o.object_ops->readdir)
+	if (!reiser4_psobj(object)->readdir)
 		return 0;
 
 	/* Main loop until all entries enumerated. */
@@ -806,129 +739,153 @@ errno_t reiser4_object_traverse(reiser4_object_t *object,
 	return res;
 }
 
-/* Creates directory. Uses params preset for all plugin. */
-reiser4_object_t *reiser4_dir_create(reiser4_fs_t *fs,
-				     reiser4_object_t *parent,
-				     const char *name)
+/* Completes object creating. */
+static reiser4_object_t *reiser4_obj_create(reiser4_object_t *parent,
+					    object_info_t *info,
+					    object_hint_t *hint,
+					    const char *name)
 {
-	object_hint_t hint;
-	tree_entity_t *tent;
+	reiser4_object_t *object;
+	entry_hint_t entry;
 	
-	aal_assert("vpf-1053", fs != NULL);
-	aal_assert("vpf-1611", fs->tree != NULL);
-	
-	aal_memset(&hint, 0, sizeof(hint));
-
-	tent = &fs->tree->ent;
+	aal_assert("vpf-1849", parent != NULL);
+	aal_assert("vpf-1849", info != NULL);
+	aal_assert("vpf-1849", info->pset.plug[PSET_OBJ] != NULL);
 	
 	/* Preparing object hint */
-	aal_memcpy(hint.info.opset.plug, tent->opset, 
-		   OPSET_LAST * sizeof(reiser4_plug_t *));
-	hint.info.opset.plug[OPSET_OBJ] = tent->opset[OPSET_MKDIR];
-	hint.info.tree = (tree_entity_t *)fs->tree;
-	hint.mode = 0;
+	/* Inherit from the parent. */
+	if (plugcall((reiser4_object_plug_t *)info->pset.plug[PSET_OBJ], 
+		     inherit, info, &parent->info))
+	{
+		return NULL;
+	}
+		
+	aal_memcpy(&info->parent, &parent->info.object, 
+		   sizeof(info->parent));
 	
+	info->tree = parent->info.tree;
+	
+	if (reiser4_object_entry_prep((reiser4_tree_t *)info->tree, 
+				      parent, &entry, name))
+	{
+		return NULL;
+	}
+	
+	entry.place_func = NULL;
+	
+	/* Creating object by passed parameters. */
+	if (!(object = reiser4_object_create(&entry, info, hint)))
+		return NULL;
+
 	if (parent) {
-		aal_memcpy(&hint.info.parent, 
-			   &parent->ent->object,
-			   sizeof(hint.info.parent));
+		if (reiser4_object_link(parent, object, &entry)) {
+			reiser4_object_clobber(object);
+			reiser4_object_close(object);
+			return NULL;
+		}
 	}
 
-	return reiser4_obj_create(parent, &hint, name);
+	return object;
+}
+
+/* Creates directory. Uses params preset for all plugin. */
+reiser4_object_t *reiser4_dir_create(reiser4_object_t *parent, 
+				     const char *name)
+{
+	object_info_t info;
+	
+	aal_assert("vpf-1053", parent != NULL);
+	
+	aal_memset(&info, 0, sizeof(info));
+	info.pset.plug[PSET_OBJ] = parent->info.tree->tset[TSET_DIRFILE];
+	info.pset.plug_mask |= (1 << PSET_OBJ);
+
+	return reiser4_obj_create(parent, &info, NULL, name);
 }
 
 /* Creates regular file, using all plugins it need from profile. Links new
    created file to @parent with @name. */
-reiser4_object_t *reiser4_reg_create(reiser4_fs_t *fs,
-				     reiser4_object_t *parent,
+reiser4_object_t *reiser4_reg_create(reiser4_object_t *parent,
 				     const char *name)
 {
-	object_hint_t hint;
-	tree_entity_t *tent;
+	object_info_t info;
 	
-	aal_assert("vpf-1054", fs != NULL);
+	aal_assert("vpf-1054", parent != NULL);
 	
-	aal_memset(&hint, 0, sizeof(hint));
-
-	tent = &fs->tree->ent;
+	aal_memset(&info, 0, sizeof(info));
+	info.pset.plug_mask |= (1 << PSET_OBJ);
+	info.pset.plug[PSET_OBJ] = parent->info.tree->tset[TSET_REGFILE];
 	
-	/* Preparing object hint */
-	aal_memcpy(hint.info.opset.plug, tent->opset, 
-		   OPSET_LAST * sizeof(reiser4_plug_t *));
-	hint.info.opset.plug[OPSET_OBJ] = tent->opset[OPSET_CREATE];
-	hint.info.tree = (tree_entity_t *)fs->tree;
-	hint.mode = 0;
-
-	if (parent) {
-		aal_memcpy(&hint.info.parent, 
-			   &parent->ent->object,
-			   sizeof(hint.info.parent));
-	}
-
-	return reiser4_obj_create(parent, &hint, name);
+	return reiser4_obj_create(parent, &info, NULL, name);
 }
 
 /* Creates symlink. Uses params preset for all plugin. */
-reiser4_object_t *reiser4_sym_create(reiser4_fs_t *fs,
-				     reiser4_object_t *parent,
+reiser4_object_t *reiser4_sym_create(reiser4_object_t *parent,
 		                     const char *name,
 		                     const char *target)
 {
 	object_hint_t hint;
-	tree_entity_t *tent;
+	object_info_t info;
 	
-	aal_assert("vpf-1186", fs != NULL);
+	aal_assert("vpf-1186", parent != NULL);
 	aal_assert("vpf-1057", target != NULL);
 	
-	tent = &fs->tree->ent;
+	aal_memset(&hint, 0, sizeof(hint));
+	hint.str = (char *)target;
 	
-	/* Preparing object hint */
-	aal_memcpy(hint.info.opset.plug, tent->opset, 
-		   OPSET_LAST * sizeof(reiser4_plug_t *));
-	hint.info.opset.plug[OPSET_OBJ] = tent->opset[OPSET_SYMLINK];
-	hint.info.tree = (tree_entity_t *)fs->tree;
-	hint.mode = 0;
-	hint.name = (char *)target;
-	
-	if (parent) {
-		aal_memcpy(&hint.info.parent, 
-			   &parent->ent->object,
-			   sizeof(hint.info.parent));
-	}
+	aal_memset(&info, 0, sizeof(info));
+	info.pset.plug[PSET_OBJ] = parent->info.tree->tset[TSET_SYMFILE];
+	info.pset.plug_mask |= (1 << PSET_OBJ);
 
-	return reiser4_obj_create(parent, &hint, name);
+	return reiser4_obj_create(parent, &info, &hint, name);
 }
 
 /* Creates special file. Uses params preset for all plugin. */
-reiser4_object_t *reiser4_spl_create(reiser4_fs_t *fs,
-				     reiser4_object_t *parent,
+reiser4_object_t *reiser4_spl_create(reiser4_object_t *parent,
 		                     const char *name,
 				     uint32_t mode,
 		                     uint64_t rdev)
 {
 	object_hint_t hint;
-	tree_entity_t *tent;
+	object_info_t info;
 	
-	aal_assert("umka-2534", fs != NULL);
+	aal_assert("umka-2534", parent != NULL);
 	aal_assert("umka-2535", rdev != 0);
 	
-	tent = &fs->tree->ent;
-	
-	/* Preparing object hint. */
-	aal_memcpy(hint.info.opset.plug, tent->opset, 
-		   OPSET_LAST * sizeof(reiser4_plug_t *));
-	hint.info.opset.plug[OPSET_OBJ] = tent->opset[OPSET_MKNODE];
-	hint.info.tree = (tree_entity_t *)fs->tree;
+	aal_memset(&hint, 0, sizeof(hint));
 	hint.mode = mode;
 	hint.rdev = rdev;
 	
-	if (parent) {
-		aal_memcpy(&hint.info.parent, 
-			   &parent->ent->object,
-			   sizeof(hint.info.parent));
-	}
+	aal_memset(&info, 0, sizeof(info));
+	info.pset.plug[PSET_OBJ] = parent->info.tree->tset[TSET_SPLFILE];
+	info.pset.plug_mask |= (1 << PSET_OBJ);
 	
-	return reiser4_obj_create(parent, &hint, name);
+	return reiser4_obj_create(parent, &info, &hint, name);
 }
 
+/* Creates special file. Uses params preset for all plugin. */
+reiser4_object_t *reiser4_ccreg_create(reiser4_object_t *parent,
+				       const char *name,
+				       const char *key)
+{
+	object_hint_t hint;
+	object_info_t info;
+	
+	aal_assert("umka-2534", parent != NULL);
+	
+	aal_memset(&hint, 0, sizeof(hint));
+	hint.str = (char *)key;
+	
+	aal_memset(&info, 0, sizeof(info));
+	info.pset.plug_mask |= (1 << PSET_OBJ);
+	
+	if (!(info.pset.plug[PSET_OBJ] = 
+	      reiser4_factory_ifind(OBJECT_PLUG_TYPE, OBJECT_CCREG40_ID))) 
+	{
+		aal_error("Can't find the CRC object plugin\n.");
+		return NULL;
+	}
+
+	return reiser4_obj_create(parent, &info, &hint, name);
+}
 #endif
