@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    semantic.c -- reiser4 semantic tree related code. */
@@ -6,21 +6,19 @@
 #include <aux/aux.h>
 #include <reiser4/libreiser4.h>
 
-struct resolve {
+typedef struct resolve {
 	bool_t follow;
 	bool_t present;
 	reiser4_object_t *parent;
 	reiser4_object_t *object;
 	reiser4_tree_t *tree;
 	reiser4_key_t key;
-};
-
-typedef struct resolve resolve_t;
+} resolve_t;
 
 /* Callback function for finding statdata of the current directory */
 static errno_t cb_find_statdata(char *path, char *entry, void *data) {
 #ifdef ENABLE_SYMLINKS
-	reiser4_plug_t *plug;
+	reiser4_object_plug_t *plug;
 #endif
 	resolve_t *resol;
 	
@@ -31,23 +29,23 @@ static errno_t cb_find_statdata(char *path, char *entry, void *data) {
 						    resol->parent,
 						    &resol->key)))
 	{
-		aal_error("Can't open object %s in %s.", entry, path);
+		aal_error("Can't open object %s given in %s.", entry, path);
 		return -EINVAL;
 	}
 	
 #ifdef ENABLE_SYMLINKS
-	plug = resol->object->ent->opset.plug[OPSET_OBJ];
+	plug = reiser4_psobj(resol->object);
 	
 	/* Symlinks handling. Method follow() should be implemented if object
 	   wants to be resolved (symlink). */
-	if (resol->follow && plug->o.object_ops->follow) {
+	if (resol->follow && plug->follow) {
 		errno_t res;
 
 		/* Calling object's follow() in order to get stat data key of
 		   the object that current object points to. */
-		res = plug_call(plug->o.object_ops, follow, resol->object->ent,
-				(resol->parent ? &resol->parent->ent->object :
-				 &resol->tree->key), &resol->key);
+		res = plugcall(plug, follow, resol->object,
+			       (resol->parent ? &resol->parent->info.object :
+				&resol->tree->key), &resol->key);
 
 	        /* Close current object. */
 		reiser4_object_close(resol->object);
@@ -73,7 +71,6 @@ static errno_t cb_find_statdata(char *path, char *entry, void *data) {
 
 /* Callback function to find @name inside the current object. */
 static errno_t cb_find_entry(char *path, char *name, void *data) {
-	reiser4_plug_t *plug;
 	entry_hint_t entry;
 	resolve_t *resol;
 	lookup_t res;
@@ -87,12 +84,12 @@ static errno_t cb_find_entry(char *path, char *name, void *data) {
 		return 0;
 	}
 	
-	plug = resol->object->ent->opset.plug[OPSET_OBJ];
-	
 	/* Looking up for @entry in current directory */
-	if ((res = plug_call(plug->o.object_ops, lookup, 
-			     resol->object->ent, name, &entry)) < 0)
+	if ((res = plugcall(reiser4_psobj(resol->object), lookup, 
+			     resol->object, name, &entry)) < 0)
+	{
 		return res;
+	}
 	
 	if (res != PRESENT) {
 		if (resol->present) {
