@@ -1,4 +1,4 @@
-/*  Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by 
+/*  Copyright 2001-2005 by Hans Reiser, licensing governed by 
     reiser4progs/COPYING.
     
     librepair/object.c - Object consystency recovery code. */
@@ -16,17 +16,18 @@ errno_t repair_object_check_struct(reiser4_object_t *object,
 	
 	aal_assert("vpf-1044", object != NULL);
 	
-	if ((res = plug_call(object->ent->opset.plug[OPSET_OBJ]->o.object_ops,
-			     check_struct, object->ent, place_func, 
-			     data, mode)) < 0)
+	if ((res = plugcall(reiser4_psobj(object), check_struct, 
+			    object, place_func, data, mode)) < 0)
+	{
 		return res;
+	}
 	
 	aal_assert("vpf-1195", mode != RM_BUILD ||
 			      !(res & RE_FATAL));
 	
-	aal_memcpy(&object->ent->object, 
+	aal_memcpy(&object->info.object, 
 		   &object_start(object)->key,
-		   sizeof(object->ent->object));
+		   sizeof(object->info.object));
 
 	return res;
 }
@@ -39,7 +40,6 @@ reiser4_object_t *repair_object_fake(reiser4_tree_t *tree,
 				     reiser4_plug_t *plug) 
 {
 	reiser4_object_t *object;
-	object_info_t info;
 
 	aal_assert("vpf-1247", tree != NULL);
 	aal_assert("vpf-1248", key != NULL);
@@ -49,45 +49,57 @@ reiser4_object_t *repair_object_fake(reiser4_tree_t *tree,
 		return INVAL_PTR;
 
 	/* Initializing info */
-	aal_memset(&info, 0, sizeof(info));
-
-	info.tree = (tree_entity_t *)tree;
-	aal_memcpy(&info.object, key, sizeof(*key));
+	aal_memcpy(&object->info.object, key, sizeof(*key));
+	
+	object->info.tree = (tree_entity_t *)tree;
+	object->info.pset.plug[PSET_OBJ] = plug;
+	object->info.pset.plug_mask |= (1 << PSET_OBJ);
 
 	if (parent) {
-		aal_memcpy(&info.parent, 
-			   &parent->ent->object, 
-			   sizeof(info.parent));
+		aal_memcpy(&object->info.parent, 
+			   &parent->info.object, 
+			   sizeof(object->info.parent));
+		
+		/* Inherit from the parent. */
+		if (plugcall(reiser4_psobj(object), inherit, 
+			     &object->info, &parent->info))
+		{
+			return NULL;
+		}
+	} else {
+		reiser4_pset_root(&object->info);
 	}
 	
 	/* Create the fake object. */
-	if (!(object->ent = plug_call(plug->o.object_ops, fake, &info)))
-		goto error_close_object;
+	if (plugcall(reiser4_psobj(object), fake, object)) {
+		aal_free(object);
+		return NULL;
+	}
 	
 	return object;
-	
- error_close_object:
-	aal_free(object);
-	return NULL;
-}
-
-static object_entity_t *cb_object_open(object_info_t *info) {
-	/* Try to init on the StatData. */
-	if (reiser4_object_init(info))
-		return INVAL_PTR;
-
-	return plug_call(info->opset.plug[OPSET_OBJ]->o.object_ops,
-			 recognize, info);
 }
 
 reiser4_object_t *repair_object_open(reiser4_tree_t *tree, 
 				     reiser4_object_t *parent,
 				     reiser4_place_t *place) 
 {
+	reiser4_object_t *object;
+	errno_t res;
+	
 	aal_assert("vpf-1622", place != NULL);
 	
-	return reiser4_object_form(tree, parent, &place->key, 
-				   place, cb_object_open);
+	if (!(object = reiser4_object_prep(tree, parent, 
+					   &place->key, place)))
+	{
+		return INVAL_PTR;
+	}
+	
+	if ((res = plugcall(reiser4_psobj(object), recognize, object))) {
+		aal_free(object);
+		return res < 0 ? INVAL_PTR : NULL;
+	}
+	
+	return object;
 }
 
 /* Open the object on the base of given start @key */
@@ -95,8 +107,10 @@ reiser4_object_t *repair_object_obtain(reiser4_tree_t *tree,
 				       reiser4_object_t *parent,
 				       reiser4_key_t *key)
 {
-	lookup_hint_t hint;
+	reiser4_object_t *object;
 	reiser4_place_t place;
+	lookup_hint_t hint;
+	errno_t res;
 
 	aal_assert("vpf-1132", tree != NULL);
 	aal_assert("vpf-1134", key != NULL);
@@ -105,12 +119,21 @@ reiser4_object_t *repair_object_obtain(reiser4_tree_t *tree,
 	hint.level = LEAF_LEVEL;
 	hint.collision = NULL;
 	
-	if (reiser4_tree_lookup(tree, &hint, FIND_EXACT, &place) < 0)
-		return INVAL_PTR;
+	if (reiser4_tree_lookup(tree, &hint, FIND_EXACT, &place) != PRESENT)
+		return NULL;
 	
-	/* Even if ABSENT, pass the found place through object recognize 
-	   method to check all possible corruptions. */
-	return reiser4_object_form(tree, parent, key, &place, cb_object_open);
+	if (!(object = reiser4_object_prep(tree, parent, key, &place))) {
+		/* FIXME: object_init fails to initialize if found item 
+		   is not SD, but this is not fatal error. */
+		return NULL;
+	}
+	
+	if ((res = plugcall(reiser4_psobj(object), recognize, object))) {
+		aal_free(object);
+		return res < 0 ? INVAL_PTR : NULL;
+	}
+	
+	return object;
 }
 
 /* Checks the attach between @parent and @object */
@@ -119,20 +142,14 @@ errno_t repair_object_check_attach(reiser4_object_t *parent,
 				   place_func_t place_func, 
 				   void *data, uint8_t mode)
 {
-	reiser4_plug_t *plug;
-	
 	aal_assert("vpf-1188", object != NULL);
-	aal_assert("vpf-1098", object->ent != NULL);
 	aal_assert("vpf-1099", parent != NULL);
-	aal_assert("vpf-1100", parent->ent != NULL);
 	
-	plug = object->ent->opset.plug[OPSET_OBJ];
-	
-	if (!plug->o.object_ops->check_attach)
+	if (!reiser4_psobj(object)->check_attach)
 		return 0;
 	
-	return plug_call(plug->o.object_ops, check_attach, object->ent, 
-			 parent->ent, place_func, data, mode);
+	return plugcall(reiser4_psobj(object), check_attach, 
+			object, parent, place_func, data, mode);
 }
 
 errno_t repair_object_mark(reiser4_object_t *object, uint16_t flag) {
@@ -143,7 +160,7 @@ errno_t repair_object_mark(reiser4_object_t *object, uint16_t flag) {
 	/* Get the start place. */
 	if ((res = reiser4_object_refresh(object))) {
 		aal_error("Update of the object [%s] failed.",
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 		return res;
 	}
 	
@@ -160,7 +177,7 @@ int repair_object_test(reiser4_object_t *object, uint16_t flag) {
 	/* Get the start place. */
 	if ((res = reiser4_object_refresh(object))) {
 		aal_error("Update of the object [%s] failed.",
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 		return res;
 	}
 	
@@ -175,7 +192,7 @@ errno_t repair_object_clear(reiser4_object_t *object, uint16_t flag) {
 	/* Get the start place. */
 	if ((res = reiser4_object_refresh(object))) {
 		aal_error("Update of the object [%s] failed.",
-			  reiser4_print_inode(&object->ent->object));
+			  reiser4_print_inode(&object->info.object));
 		return res;
 	}
 	
@@ -188,25 +205,21 @@ errno_t repair_object_clear(reiser4_object_t *object, uint16_t flag) {
    with the object. For now it is only updating the parent pointer. 
    Should be called after repair_object_obtain, repair_object_check_sytict. */
 errno_t repair_object_refresh(reiser4_object_t *object) {
-	reiser4_plug_t *plug;
 	entry_hint_t entry;
 	
 	aal_assert("vpf-1271", object != NULL);
 
-	plug = object->ent->opset.plug[OPSET_OBJ];
-	
-	if (!plug->o.object_ops->lookup)
+	if (!reiser4_psobj(object)->lookup)
 		return 0;
 
-	switch (plug_call(plug->o.object_ops, lookup, 
-			  object->ent, "..", &entry))
+	switch (plugcall(reiser4_psobj(object), lookup, object, "..", &entry))
 	{
 	case ABSENT:
-		aal_memset(&object->ent->parent, 0, 
-			   sizeof(object->ent->parent));
+		aal_memset(&object->info.parent, 0, 
+			   sizeof(object->info.parent));
 		break;
 	case PRESENT:
-		aal_memcpy(&object->ent->parent, 
+		aal_memcpy(&object->info.parent, 
 			   &entry.object, sizeof(entry.object));
 		break;
 	default:
