@@ -8,17 +8,17 @@
 
 reiser4_core_t *cde40_core = NULL;
 
-inline uint32_t cde40_key_pol(reiser4_place_t *place) {
+uint32_t cde40_key_pol(reiser4_place_t *place) {
 	return plugcall(place->key.plug, bodysize);
 }
 
 /* Returns pointer to entry */
-inline void *cde40_entry(reiser4_place_t *place, uint32_t pos) {
+void *cde40_entry(reiser4_place_t *place, uint32_t pos) {
 	return cde_get_entry(place, pos, cde40_key_pol(place));
 }
 
 /* Returns pointer to the objectid entry component. */
-inline void *cde40_objid(reiser4_place_t *place, uint32_t pos) {
+void *cde40_objid(reiser4_place_t *place, uint32_t pos) {
 	return (place->body + en_get_offset(cde40_entry(place, pos),
 					    cde40_key_pol(place)));
 }
@@ -798,12 +798,8 @@ static int64_t cde40_insert_units(reiser4_place_t *place, trans_hint_t *hint) {
 errno_t cde40_delete(reiser4_place_t *place, uint32_t pos,
 		     trans_hint_t *hint)
 {
-	uint32_t pol;
-
 	aal_assert("umka-3024", pos < cde40_units(place));
 
-	pol = cde40_key_pol(place);
-	
 	/* Shrinking cde item */
 	hint->bytes = hint->len = cde40_shrink(place, pos, hint->count);
 	
