@@ -1,4 +1,4 @@
-/* Copyright 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    nodeptr40_repair.c -- repair default node pointer item plugin methods. */
@@ -26,9 +26,11 @@ errno_t nodeptr40_check_layout(reiser4_place_t *place,
 	
 	if (res > 0) {
 		fsck_mess("Node (%llu), item (%u): wrong pointer to "
-			  "the block %llu.%s", place_blknr(place),
-			  place->pos.item, blk, hint->mode == RM_BUILD ?
-			  " Removed." : "");
+			  "the block %llu.%s",
+			  (unsigned long long)place_blknr(place),
+			  place->pos.item,
+			  (unsigned long long)blk,
+			  hint->mode == RM_BUILD ? " Removed." : "");
 
 		if (hint->mode == RM_BUILD) {
 			hint->len = place->len;
@@ -59,7 +61,7 @@ void nodeptr40_print(reiser4_place_t *place, aal_stream_t *stream,
     
 	nodeptr = nodeptr40_body(place);
 
-	aal_stream_format(stream, "[%llu]\n", 
+	aal_stream_format(stream, " [%llu]\n", 
 			  np40_get_ptr(nodeptr));
 }
 #endif
