@@ -17,7 +17,8 @@ errno_t sdext_flags_check_struct(stat_entity_t *stat, repair_hint_t *hint) {
 	if (stat->offset + sizeof(sdext_flags_t) > stat->place->len) {
 		fsck_mess("Node (%llu), item (%u), [%s]: does not look "
 			  "like a valid (%s) statdata extension.", 
-			  place_blknr(stat->place), stat->place->pos.item,
+			  (unsigned long long)place_blknr(stat->place),
+			  stat->place->pos.item,
 			  print_key(sdext_flags_core, &stat->place->key),
 			  stat->plug->p.label);
 		return RE_FATAL;
