@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
    sdext_lt_repair.c -- large time stat data extension plugin recovery code. */
@@ -11,14 +11,15 @@
 
 errno_t sdext_lt_check_struct(stat_entity_t *stat, repair_hint_t *hint) {
 	aal_assert("vpf-776", stat != NULL);
-	aal_assert("vpf-782", stat->ext_plug != NULL);
+	aal_assert("vpf-782", stat->plug != NULL);
 	
 	if (stat->offset + sizeof(sdext_lt_t) > stat->place->len) {
 		fsck_mess("Node (%llu), item (%u), [%s]: does not look "
 			  "like a valid (%s) statdata extension.", 
-			  place_blknr(stat->place), stat->place->pos.item,
+			  (unsigned long long)place_blknr(stat->place),
+			  stat->place->pos.item,
 			  print_key(sdext_lt_core, &stat->place->key),
-			  stat->ext_plug->label);
+			  stat->plug->p.label);
 		return RE_FATAL;
 	}
 	
