@@ -1,7 +1,7 @@
-/* Copyright (C) 2001, 2002, 2003, 2004 by Hans Reiser, licensing governed by
+/* Copyright (C) 2001-2005 by Hans Reiser, licensing governed by
    reiser4progs/COPYING.
    
-   sdext_unix.h -- stat data exception plugin, that implements unix stat data
+   sdext_unix.h -- stat data extention plugin, that implements unix stat data
    fields. */
 
 #ifndef SDEXT_UNIX_H
@@ -10,7 +10,7 @@
 #include <aal/libaal.h>
 #include <reiser4/plugin.h>
 
-struct sdext_unix {
+typedef struct sdext_unix {
 	d32_t uid;
 	d32_t gid;
 	d32_t atime;
@@ -20,9 +20,7 @@ struct sdext_unix {
 		d64_t rdev;
 		d64_t bytes;
 	} u;
-} __attribute__((packed));
-
-typedef struct sdext_unix sdext_unix_t;
+} __attribute__((packed)) sdext_unix_t;
 
 extern reiser4_core_t *sdext_unix_core;
 
@@ -41,7 +39,7 @@ extern reiser4_core_t *sdext_unix_core;
 #define sdext_unix_get_ctime(ext)	aal_get_le32(ext, ctime)
 #define sdext_unix_set_ctime(ext, val)	aal_set_le32(ext, ctime, val)
 
-#define sdext_unix_get_rdev(ext)	        aal_get_le64(ext, u.rdev)
+#define sdext_unix_get_rdev(ext)	aal_get_le64(ext, u.rdev)
 #define sdext_unix_set_rdev(ext, val)	aal_set_le64(ext, u.rdev, val)
 
 #define sdext_unix_get_bytes(ext)	aal_get_le64(ext, u.bytes)
